@@ -46,23 +46,18 @@ AkonadiIndexingAgent::AkonadiIndexingAgent(const QString &id)
     Akonadi::AttributeFactory::registerAttribute<Akonadi::IndexPolicyAttribute>();
 
     KConfigGroup cfg = config()->group("General");
-    int agentIndexingVersion = cfg.readEntry("agentIndexingVersion", 0);
-    if (agentIndexingVersion == 0) {
-        // Check for value in baloorc, which we used historically, and migrate
-        // to the native config file
-        KConfig baloorc(QStringLiteral("baloorc"));
-        KConfigGroup baloorcGroup = baloorc.group("Akonadi");
-        agentIndexingVersion = baloorcGroup.readEntry("agentIndexingVersion", 0);
-        cfg.writeEntry("agentIndexingVersion", agentIndexingVersion);
-    }
-
+    const int agentIndexingVersion = cfg.readEntry("agentIndexingVersion", 0);
+    bool respectDiacriticAndAccents = cfg.readEntry("respectDiacriticAndAccents", true);
     if (agentIndexingVersion < INDEXING_AGENT_VERSION) {
         m_index.removeDatabase();
+        // Don't respect Diacritic and Accents in new Database so search will be more easy.
+        respectDiacriticAndAccents = false;
         QTimer::singleShot(0, &m_scheduler, &Scheduler::scheduleCompleteSync);
         cfg.writeEntry("agentIndexingVersion", INDEXING_AGENT_VERSION);
+        cfg.writeEntry("respectDiacriticAndAccents", respectDiacriticAndAccents);
         cfg.sync();
     }
-
+    m_index.setRespectDiacriticAndAccents(respectDiacriticAndAccents);
     if (!m_index.createIndexers()) {
         Q_EMIT status(Broken, i18nc("@info:status", "No indexers available"));
         setOnline(false);
@@ -107,9 +102,7 @@ AkonadiIndexingAgent::AkonadiIndexingAgent(const QString &id)
     }
 }
 
-AkonadiIndexingAgent::~AkonadiIndexingAgent()
-{
-}
+AkonadiIndexingAgent::~AkonadiIndexingAgent() = default;
 
 void AkonadiIndexingAgent::reindexAll()
 {
@@ -318,14 +311,6 @@ void AkonadiIndexingAgent::onOnlineChanged(bool online)
         // We only reindex if this is not a regular start
         KConfigGroup cfg = config()->group("General");
         bool aborted = cfg.readEntry("aborted", false);
-        if (!aborted) {
-            // Check baloorc which we used historically to make sure we don't
-            // miss the value
-            // TODO: Unfortunately we will hit this path in most cases
-            KConfig baloorc(QStringLiteral("baloorc"));
-            KConfigGroup baloorcgroup = baloorc.group("Akonadi");
-            aborted = baloorcgroup.readEntry("aborted", false);
-        }
         if (aborted) {
             cfg.writeEntry("aborted", false);
             cfg.sync();
